========================
Ditto Hunt Release Notes
========================

Version 1.1     16 July 2017
----------------------------
- Fix README install instructions.
- Show number of files in confirmation dialogs
- Rework options for searching
- Add refresh button
- Add menu option to copy path to clipboard
- Add handling of FindThread errors
- Fix PyQt5 issue where progress dialog sometimes ghosts
- Fix bug where status is not updated
- Add expand/collapse actions
- Add move button
- Handle and show errors from FindThread
- Show open menu for all tree items
- Show PREVIEW in preview label when no image
- Add tooltips for GUI widgets
- Make statusbar message permanent

Version 1.0     15 July 2017
----------------------------
- Initial alpha release.
